aboutsummaryrefslogtreecommitdiffstats
path: root/ports/darwin/guts/getxattr.c
diff options
context:
space:
mode:
Diffstat (limited to 'ports/darwin/guts/getxattr.c')
-rw-r--r--ports/darwin/guts/getxattr.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/ports/darwin/guts/getxattr.c b/ports/darwin/guts/getxattr.c
index 16f0993..ecef9cf 100644
--- a/ports/darwin/guts/getxattr.c
+++ b/ports/darwin/guts/getxattr.c
@@ -1,12 +1,12 @@
/*
- * Copyright (c) 2011 Wind River Systems; see
+ * Copyright (c) 2014 Wind River Systems; see
* guts/COPYRIGHT for information.
*
* ssize_t getxattr(const char *pathname, const char *name, void *value, size_t size, u_int32_t position, int options)
* ssize_t rc = -1;
*/
- rc = real_getxattr(pathname, name, value, size, position, options);
+ rc = shared_getxattr(path, -1, name, value, size, position, options);
/* return rc;
* }
@@ -1,12 +1,12 @@
* guts/COPYRIGHT for information.
*
- * ssize_t getxattr(const char *pathname, const char *name, void *value, size_t size, u_int32_t position, int options)
+ * ssize_t getxattr(const char *path, const char *name, void *value, size_t size, u_int32_t position, int options)
* ssize_t rc = -1;
*/